@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2016 - 2024 -- Lars Heuer
 # All rights reserved.
@@ -16,10 +15,10 @@ from itertools import chain
 import shutil
 import nox
 
-_PY_VERSIONS = ('3.5', '3.6', '3.7', '3.8', '3.9', '3.10', '3.11', '3.12', 'pypy3')
+_PY_VERSIONS = ('3.9', '3.10', '3.11', '3.12', '3.13', 'pypy3')
 _PY_DEFAULT_VERSION = sys.version[:4]
 
-nox.options.sessions = chain(['test-{}'.format(version) for version in _PY_VERSIONS], ['coverage', 'lint'])
+nox.options.sessions = chain([f'test-{version}' for version in _PY_VERSIONS], ['coverage', 'lint'])
 
 
 @nox.session(python=_PY_VERSIONS)
@@ -29,7 +28,10 @@ def test(session):
     """
     session.install('-Ur', 'tests/requirements.txt')
     session.install('.')
-    session.run('py.test')
+    if session.posargs:
+        session.run('pytest', *[f'tests/{test_file}' for test_file in session.posargs])
+    else:
+        session.run('pytest')
 
 
 @nox.session(python=_PY_DEFAULT_VERSION)
@@ -50,7 +52,7 @@ def docs(session):
     import segno
     if 'dev' not in segno.__version__:
         shutil.copyfile(os.path.join(man, 'segno.1'),
-                        os.path.abspath(os.path.join(os.path.dirname(__file__), 'man', 'segno.1')))
+                        os.path.abspath(os.path.join(os.path.dirname(__file__), 'data/share/man/man1/', 'segno.1')))
         session.log("'man/segno.1' has been modified, don't forget to commit")
 
 
@@ -62,18 +64,17 @@ def coverage(session):
     session.install('-Ur', 'tests/requirements.txt')
     session.install('.')
     html_output_dir = os.path.abspath(os.path.join(session.create_tmp(), 'html'))
-    session.run('pytest', '--cov=segno', '--cov-report=term', '--cov-report=html:%s' % html_output_dir)
+    session.run('pytest', '--cov=segno', '--cov-report=term', f'--cov-report=html:{html_output_dir}')
 
 
 @nox.session(python=_PY_DEFAULT_VERSION)
 def lint(session):
     """\
-    Run flake8
+    Run linters.
     """
-    session.install('flake8', 'mypy')
+    session.install('ruff', 'mypy')
     session.run('mypy', 'segno')
-    session.run('flake8', 'segno')
-    session.run('flake8', 'tests')
+    session.run('ruff', 'check', '.')
 
 
 @nox.session(python=_PY_DEFAULT_VERSION)
@@ -113,20 +114,21 @@ def start_release(session):
     git('checkout', 'master')
     prev_version = _get_current_version(session)
     version = _validate_version(session)
-    valid_version = bool(int(session.run('python', '-c', 'from packaging.version import parse;'
-                                                         'prev_version = parse("{0}");'
-                                                         'next_version = parse("{1}");'
-                                                         'print(1 if prev_version < next_version else 0)'
-                                         .format(prev_version, version), silent=True)))
+    valid_version = bool(int(session.run('python', '-c',
+                                            'from packaging.version import parse;'
+                                            f'prev_version = parse("{prev_version}");'
+                                            f'next_version = parse("{version}");'
+                                            'print(1 if prev_version < next_version else 0)',
+                                         silent=True)))
     if not valid_version:
         session.error('Invalid version')
-    release_branch = 'release-{}'.format(version)
+    release_branch = f'release-{version}'
     git('checkout', '-b', release_branch, 'master')
     _change_version(session, prev_version, version)
     git('add', 'segno/__init__.py')
-    session.log('Now on branch "{}". Run the tests, run nox -e docs. Update and add CHANGES'.format(release_branch))
+    session.log(f'Now on branch "{release_branch}". Run the tests, run nox -e docs. Update and add CHANGES')
     session.log('Commit any changes.')
-    session.log('When done, call nox -e finish-release -- {}'.format(version))
+    session.log(f'When done, call nox -e finish-release -- {version}')
 
 
 @nox.session(name='finish-release', python=_PY_DEFAULT_VERSION)
@@ -139,11 +141,11 @@ def finish_release(session):
     * Increments the development version
     """
     version = _validate_version(session)
-    release_branch = 'release-{}'.format(version)
+    release_branch = f'release-{version}'
     git = partial(session.run, 'git', external=True)
     git('checkout', 'master')
-    git('merge', '--no-ff', release_branch, '-m', 'Merge release branch {}'.format(release_branch))
-    git('tag', '-a', version, '-m', 'Release {}'.format(version))
+    git('merge', '--no-ff', release_branch, '-m', f'Merge release branch {release_branch}')
+    git('tag', '-a', version, '-m', f'Release {version}')
     git('branch', '-d', release_branch)
     version_parts = version.split('.')
     patch = str(int(version_parts[2]) + 1)
@@ -152,7 +154,7 @@ def finish_release(session):
     git('add', 'segno/__init__.py')
     git('commit', '-m', 'Incremented development version')
     session.log('Finished. Run git push / git push origin --tags and '
-                'nox -e build-release -- {} / nox -e upload-release'.format(version))
+                f'nox -e build-release -- {version} / nox -e upload-release')
 
 
 @nox.session(name='build-release', python=_PY_DEFAULT_VERSION)
@@ -161,13 +163,13 @@ def build_release(session):
     Builds a release: Creates sdist and wheel
     """
     version = _validate_version(session)
-    session.install('build', 'wheel')
+    session.install('flit-core')
     git = partial(session.run, 'git', external=True)
     git('fetch')
     git('fetch', '--tags')
     git('checkout', version)
     shutil.rmtree('dist', ignore_errors=True)
-    session.run('python', '-m', 'build', '--no-isolation')
+    session.run('flit', 'build', external=True)
     git('checkout', 'master')
 
 
@@ -189,7 +191,7 @@ def _validate_version(session):
         session.error('Too many arguments')
     version = session.posargs[0]
     if not re.match(r'^[0-9]+\.[0-9]+\.[0-9]+$', version):
-        session.error('Invalid version number: "{}"'.format(version))
+        session.error(f'Invalid version number: "{version}"')
     return version
 
 
@@ -198,7 +200,7 @@ def _get_current_version(session):
     Returns the current Segno version.
     """
     fn = os.path.abspath(os.path.join(os.path.dirname(__file__), 'segno/__init__.py'))
-    with open(fn, 'r', encoding='utf-8') as f:
+    with open(fn, encoding='utf-8') as f:
         content = f.read()
     m = re.search(r'^__version__ = ["\']([^"\']+)["\']$', content, flags=re.MULTILINE)
     if m:
@@ -211,15 +213,13 @@ def _change_version(session, previous_version, next_version):
     Changes the segno.__init__.__version__ from previous_version to next_version.
     """
     fn = os.path.abspath(os.path.join(os.path.dirname(__file__), 'segno/__init__.py'))
-    with open(fn, 'r', encoding='utf-8') as f:
+    with open(fn, encoding='utf-8') as f:
         content = f.read()
-    new_content = re.sub(r'^(__version__ = ["\'])({0})(["\'])$'
-                         .format(re.escape(previous_version)),
-                         r'\g<1>{}\g<3>'.format(next_version), content,
+    new_content = re.sub(rf'^(__version__ = ["\'])({re.escape(previous_version)})(["\'])$',
+                         rf'\g<1>{next_version}\g<3>', content,
                          flags=re.MULTILINE)
     if content != new_content:
         with open(fn, 'w', encoding='utf-8') as f:
             f.write(new_content)
         return
-    session.error('Cannot modify version. Provided: "{}" (previous) "{}" (next)'
-                  .format(previous_version, next_version))
+    session.error(f'Cannot modify version. Provided: "{previous_version}" (previous) "{next_version}" (next)')
