@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2016 - 2024 -- Lars Heuer
 # All rights reserved.
@@ -16,7 +15,7 @@ from . import encoder
 from .encoder import DataOverflowError
 from . import writers, utils
 
-__version__ = '1.6.1'
+__version__ = '1.6.6'
 
 __all__ = ('make', 'make_qr', 'make_micro', 'make_sequence', 'QRCode',
            'QRCodeSequence', 'DataOverflowError')
@@ -214,7 +213,7 @@ class QRCode:
     """\
     Represents a (Micro) QR Code.
     """
-    __slots__ = ('matrix', 'mask', '_version', '_error', '_mode', '_matrix_size')
+    __slots__ = ('_error', '_matrix_size', '_mode', '_version', 'mask', 'matrix')
 
     def __init__(self, code):
         """\
@@ -424,7 +423,7 @@ class QRCode:
         f = tempfile.NamedTemporaryFile('wb', suffix='.png', delete=False)
         try:
             self.save(f, scale=scale, dark=dark, light=light, border=border)
-        except:  # noqa: E722
+        except:
             f.close()
             os.unlink(f.name)
             raise
@@ -961,8 +960,7 @@ class QRCode:
                                             name=name[3:]):
                 plugin = ep.load()
                 return partial(plugin, self)
-        raise AttributeError('{0} object has no attribute {1}'
-                             .format(self.__class__, name))
+        raise AttributeError(f'{self.__class__} object has no attribute {name}')
 
 
 class QRCodeSequence(tuple):
@@ -974,7 +972,7 @@ class QRCodeSequence(tuple):
     __slots__ = ()
 
     def __new__(cls, qrcodes):
-        return super(QRCodeSequence, cls).__new__(cls, qrcodes)
+        return super().__new__(cls, qrcodes)
 
     def terminal(self, out=None, border=None, compact=False):
         """\
@@ -1016,5 +1014,4 @@ class QRCodeSequence(tuple):
         """
         if len(self) == 1:
             return getattr(self[0], item)
-        raise AttributeError("{0} object has no attribute '{1}'"
-                             .format(self.__class__, item))
+        raise AttributeError(f"{self.__class__} object has no attribute '{item}'")
