@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2024 -- Lars Heuer
 # All rights reserved.
@@ -9,7 +8,6 @@
 Test against PR 124
 <https://github.com/heuer/segno/pull/124>
 """
-from __future__ import unicode_literals, absolute_import
 import pytest
 from segno import helpers
 
