@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2016 - 2024 -- Lars Heuer
 # All rights reserved.
@@ -9,7 +8,6 @@
 Tests against issue 35
 <https://github.com/heuer/segno/issues/35>
 """
-from __future__ import absolute_import, unicode_literals
 import pytest
 from segno import consts
 from segno import encoder
