@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2016 - 2024 -- Lars Heuer
 # All rights reserved.
@@ -9,7 +8,6 @@
 Tests against issue #45.
 <https://github.com/heuer/segno/issues/45>
 """
-from __future__ import unicode_literals, absolute_import
 from segno import cli
 import pytest
 
