@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2016 - 2024 -- Lars Heuer
 # All rights reserved.
@@ -13,7 +12,6 @@ see the above mentioned pull request.
 
 Adapted for Segno to check if it suffers from the same problem.
 """
-from __future__ import absolute_import, unicode_literals
 import segno
 
 
