@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2016 - 2024 -- Lars Heuer
 # All rights reserved.
@@ -9,7 +8,6 @@
 Test against issue #29.
 <https://github.com/heuer/segno/issues/29>
 """
-from __future__ import absolute_import, unicode_literals
 import os
 import io
 import tempfile
